@@ -13,12 +13,9 @@ import httpx
 from zeroconf import DNSQuestionType, ServiceInfo, ServiceStateChange, Zeroconf
 from zeroconf.asyncio import AsyncServiceBrowser, AsyncServiceInfo, AsyncZeroconf
 
-from .device_api import SERVICE_TYPE as DEVICEAPI
-from .device_api import DeviceApi
+from .device_api import SERVICE_TYPE as DEVICEAPI, DeviceApi
 from .exceptions.device import DeviceNotFound
-from .plcnet_api import DEVICES_WITHOUT_PLCNET
-from .plcnet_api import SERVICE_TYPE as PLCNETAPI
-from .plcnet_api import PlcNetApi
+from .plcnet_api import DEVICES_WITHOUT_PLCNET, SERVICE_TYPE as PLCNETAPI, PlcNetApi
 from .zeroconf import ZeroconfServiceInfo
 
 
@@ -32,11 +29,14 @@ class Device:  # pylint: disable=too-many-instance-attributes
     :param zeroconf_instance: Zeroconf instance to be potentially reused.
     """
 
+    MDNS_TIMEOUT = 300
+
     def __init__(
         self,
         ip: str,
         zeroconf_instance: AsyncZeroconf | Zeroconf | None = None,
     ) -> None:
+        """Initialize the device."""
         self.ip = ip
         self.mac = ""
         self.mt_number = "0"
@@ -47,6 +47,7 @@ class Device:  # pylint: disable=too-many-instance-attributes
         self.device: DeviceApi | None = None
         self.plcnet: PlcNetApi | None = None
 
+        self._background_tasks: set[asyncio.Task] = set()
         self._browser: dict[str, AsyncServiceBrowser] = {}
         self._connected = False
         self._info: dict[str, ZeroconfServiceInfo] = {PLCNETAPI: ZeroconfServiceInfo(), DEVICEAPI: ZeroconfServiceInfo()}
@@ -61,21 +62,26 @@ class Device:  # pylint: disable=too-many-instance-attributes
         self._zeroconf: AsyncZeroconf
 
     def __del__(self) -> None:
+        """Warn user, if the connection was not properly closed."""
         if self._connected and self._session_instance is None:
             self._logger.warning("Please disconnect properly from the device.")
 
     async def __aenter__(self) -> Device:
+        """Connect to a device asynchronously when entering a context manager."""
         await self.async_connect()
         return self
 
     async def __aexit__(self, exc_type: type | None, exc_val: BaseException | None, exc_tb: TracebackType | None) -> None:
+        """Disconnect to a device asynchronously when entering a context manager."""
         await self.async_disconnect()
 
     def __enter__(self) -> Device:
+        """Connect to a device synchronously when leaving a context manager."""
         self.connect()
         return self
 
     def __exit__(self, exc_type: type | None, exc_val: BaseException | None, exc_tb: TracebackType | None) -> None:
+        """Disconnect to a device synchronously when leaving a context manager."""
         self.disconnect()
 
     @property
@@ -104,6 +110,8 @@ class Device:  # pylint: disable=too-many-instance-attributes
         self._password = password
         if self.device:
             self.device.password = password
+        if self.plcnet:
+            self.plcnet.password = password
 
     async def async_connect(self, session_instance: httpx.AsyncClient | None = None) -> None:
         """
@@ -121,7 +129,7 @@ class Device:  # pylint: disable=too-many-instance-attributes
             self._zeroconf = self._zeroconf_instance
         await asyncio.gather(self._get_device_info(), self._get_plcnet_info())
         if not self.device and not self.plcnet:
-            raise DeviceNotFound(f"The device {self.ip} did not answer.")
+            raise DeviceNotFound(self.ip)
         self._connected = True
 
     def connect(self) -> None:
@@ -168,6 +176,7 @@ class Device:  # pylint: disable=too-many-instance-attributes
             self.mac = self._info[service_type].properties["PlcMacAddress"]
             self.technology = self._info[service_type].properties.get("PlcTechnology", "")
             self.plcnet = PlcNetApi(ip=self.ip, session=self._session, info=self._info[service_type])
+            self.plcnet.password = self.password
 
     async def _get_zeroconf_info(self, service_type: str) -> None:
         """Browse for the desired mDNS service types and query them."""
@@ -182,7 +191,7 @@ class Device:  # pylint: disable=too-many-instance-attributes
             addr=addr,
             question_type=question_type,
         )
-        while not self._info[service_type].properties and counter < 300:
+        while not self._info[service_type].properties and counter < self.MDNS_TIMEOUT:
             counter += 1
             await asyncio.sleep(0.01)
 
@@ -198,7 +207,9 @@ class Device:  # pylint: disable=too-many-instance-attributes
         """Evaluate the query result."""
         if state_change == ServiceStateChange.Removed:
             return
-        asyncio.create_task(self._get_service_info(zeroconf, service_type, name))
+        task = asyncio.create_task(self._get_service_info(zeroconf, service_type, name))
+        self._background_tasks.add(task)
+        task.add_done_callback(self._background_tasks.remove)
 
     async def _get_service_info(self, zeroconf: Zeroconf, service_type: str, name: str) -> None:
         """Get service information, if IP matches."""
