@@ -1,9 +1,9 @@
-"""Fixture for protobuf tests."""
+"""Fixtures for protobuf tests."""
 from typing import AsyncGenerator
 
 import pytest_asyncio
 
-from ..stubs.protobuf import StubProtobuf
+from tests.stubs.protobuf import StubProtobuf
 
 
 @pytest_asyncio.fixture()
