@@ -4,13 +4,14 @@ from httpx import AsyncClient
 from devolo_plc_api.clients import Protobuf
 from devolo_plc_api.plcnet_api import SERVICE_TYPE
 
-from .. import load_test_data
+from tests import load_test_data
 
 
 class StubProtobuf(Protobuf):
     """Protobuf object with pre-filled information."""
 
     def __init__(self) -> None:
+        """Initialize the client."""
         test_data = load_test_data()
         super().__init__()
         self._ip = test_data.ip
